/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter;

import java.util.List;

import de.bsvrz.ibv.uda.interpreter.daten.fehler.ArgumentFehler;
import de.bsvrz.ibv.uda.interpreter.daten.fehler.UdaFehlerSubtyp;
import de.bsvrz.sys.funclib.bitctrl.interpreter.HandlerValidation;
import de.bsvrz.sys.funclib.bitctrl.interpreter.NichtWert;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Operator;

/**
 * Handler für allgemeine Funktionen und Operatoren, die innerhalb eines
 * UdaSkripts verwendet werden können.<br>
 * Folgende Operationen werden unterstützt:
 * <ul>
 * <li><b>klasse():</b> liefert den Namen der Klasse eines Objekts</li>
 * </ul>
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class InterpreterHandler extends AbstractUdaHandler {

	/**
	 * {@inheritDoc}.
	 *
	 * @return die Liste der Operatoren, die unterstützt werden.
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#getHandledOperators()
	 */
	@Override
	public Operator[] getHandledOperators() {
		return InterpreterHandlerOperatoren.OPERATOREN;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#perform(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public Object perform(final Operator operator, final List<Object> operanden) {
		Object result = NichtWert.NICHTWERT;

		erzeugeHandlerFehler(operator, operanden);

		if (InterpreterHandlerOperatoren.KLASSE.equals(operator)) {
			result = operanden.get(0).getClass().getName();
		} else if (InterpreterHandlerOperatoren.ERZEUGE_KOPIE.equals(operator)) {
			final Object obj = operanden.get(0);
			if (obj instanceof Kopierbar) {
				result = ((Kopierbar) obj).erzeugeKopie();
			} else {
				result = new ArgumentFehler(UdaFehlerSubtyp.ARGUMENTE,
						"Die Erstellung eines Kopie eines Datums vpm Typ: \"" + obj.getClass().getName()
								+ "\" wird nicht unterstützt");
			}
		}
		return result;
	}

	/**
	 * {@inheritDoc}.
	 *
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Handler#validiereHandler(de.bsvrz.sys.funclib.bitctrl.interpreter.Operator,
	 *      java.util.List)
	 */
	@Override
	public HandlerValidation validiereHandler(final Operator operator, final List<? extends Object> operanden) {
		boolean result = false;
		if (InterpreterHandlerOperatoren.KLASSE.equals(operator)) {
			if (operanden.size() == 1) {
				result = true;
			}
		} else if (InterpreterHandlerOperatoren.ERZEUGE_KOPIE.equals(operator)) {
			if (operanden.size() == 1) {
				result = true;
			}
		}
		return new HandlerValidation(result, true);
	}

}
