/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.anweisung;

import de.bsvrz.ibv.uda.interpreter.daten.konstante.ZeichenkettenLiteral;
import de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext;

/**
 * die Repräsentation einer BenutzeAnweisung innerhalb eines UdaSkripts.<br>
 * Die BenutzeAnweisung wird verwendet, um andere Skripts in ein Skript
 * einzubinden. In der Praxis können damit Bibliothen mit wiederverwendbaren
 * Elementen (Funktionen, Quantoren) in andere Skripts eingebunden werden ohne
 * diese innerhalb jeden Skripts gesondert zu beschreiben. Die BenzuteAnweisung
 * wird bereits bei der Übersetzung des vom Parser gelieferten AST eines Skripts
 * in eine vom Interpreter ausführbare Struktur ausgewertet. Die Auswertung der
 * BenutzeAnweisung entspricht damit der Einbindung der Interpreter-Struktur des
 * einzubindenden Skripts in das einbindende Skript.
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public class BenutzeAnweisung extends AbstractEinfacheAnweisung {

	/**
	 * der Name des einzubindenen Skripts.
	 */
	private final ZeichenkettenLiteral benutzt;

	/**
	 * Konstruktor.<br>
	 *
	 * @param zeile
	 *            die Zeile innerhalb des Quelltextes, in der die Anweisung
	 *            definiert wird
	 * @param skriptname
	 *            der name des Skripts, in dem die Anweisung definiert ist
	 * @param benutzt
	 *            der Name des einzubindenden Skripts
	 */
	public BenutzeAnweisung(final int zeile, final String skriptname, final ZeichenkettenLiteral benutzt) {
		super(zeile, skriptname, null);
		this.benutzt = benutzt;
	}

	/**
	 * bewertet den Ausdruck.<br>
	 * Die Funktion liefert den Name des einzubindenen Skripts zurück. Bei der
	 * Umsetzung des einbindenden Skripts wird eine BenutzeAnweisung sofort
	 * ausgewertet, in dem der Text des eingebundenen Skriptes geparst,
	 * umgesetzt und in die Struktur des einbindenden Skripts integriert wird.
	 * <br>
	 *
	 * @param kontext
	 *            der Kontext, in dem der Ausdruck ausgewertet wird
	 * @return den Namen
	 * @see de.bsvrz.sys.funclib.bitctrl.interpreter.Ausdruck#interpret(de.bsvrz.sys.funclib.bitctrl.interpreter.Kontext)
	 */
	@Override
	public String interpret(final Kontext kontext) {
		return benutzt.interpret(null);
	}
}
