/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.3 Umfassende Datenanalyse
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.uda.interpreter.daten.dav;

import de.bsvrz.dav.daf.main.DataAndATGUsageInformation;

/**
 * Repräsentation eines Datenverteilerobjekts vom Typ
 * {@link DataAndATGUsageInformation} innerhalb eines UDA-Sktipts.
 *
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class DataAndAtgUsageInformationObjekt {

	/**
	 * der Aspekt des Objekts.
	 */
	private final AspektObjekt asp;

	/**
	 * die Attributgruppe des Objekts.
	 */
	private final AtgObjekt atg;

	/**
	 * die zugeordneten Daten.
	 */
	private final DavDatenObjekt daten;

	/**
	 * Konstruktor.
	 *
	 * @param atgObj
	 *            die Attributgruppe als UDA-Objekt
	 * @param aspObj
	 *            der Aspekt als UDA-Objekt
	 * @param davDatenObjekt
	 *            die Daten als UDA-Datenverteilerdatenobjekt
	 */
	public DataAndAtgUsageInformationObjekt(final AtgObjekt atgObj, final AspektObjekt aspObj,
			final DavDatenObjekt davDatenObjekt) {
		this.atg = atgObj;
		this.asp = aspObj;
		this.daten = davDatenObjekt;
	}

	/**
	 * erzeugt das entsprechende DAF-Objekt.
	 *
	 * @return das erzeugte Objekt
	 */
	public DataAndATGUsageInformation getDavInformation() {
		return new DataAndATGUsageInformation(atg.getObjekt().getAttributeGroupUsage(asp.getObjekt()),
				daten.getObjekt());
	}
}
